import html2canvas from 'html2canvas'

const getPixelRatio = (context) => {
  let backingStore = context.backingStorePixelRatio ||
    context.webkitBackingStorePixelRatio ||
    context.mozBackingStorePixelRatio ||
    context.msBackingStorePixelRatio ||
    context.oBackingStorePixelRatio ||
    context.backingStorePixelRatio || 1;
    return (window.devicePixelRatio || 1) / backingStore;
}

const exportImg = (img, imgName) => {
  return new Promise((resolve, reject) => {
    let a = document.createElement('a');
    a.setAttribute('href', img);
    a.setAttribute("download", imgName);
    document.body.appendChild(a)
    a.click();
    a.remove();
    resolve();
  })
}

const captureImg = async (dom, imgName) => {
  return new Promise(async (resolve, reject) => {
    let width = dom.scrollWidth;  // 获取(原生）dom 宽度
    let height = dom.scrollHeight; // 获取(原生）dom 高
  
    let canvas = document.createElement('canvas');  //创建canvas 对象
    let context = canvas.getContext('2d');
    let scale = getPixelRatio(context);  //获取像素密度的方法 (也可以采用自定义缩放比例)
    canvas.width = width * scale;   //这里 由于绘制的dom 为固定宽度，居中，所以没有偏移
    canvas.height = height * scale;  // 注意高度问题，由于顶部有个距离所以要加上顶部的距离，解决图像高度偏移问题
    context.scale(1, 1);
  
    let opts = {
      allowTaint: true,//允许加载跨域的图片
      tainttest: true, //检测每张图片都已经加载完成
      scale: scale, // 添加的scale 参数
      canvas: canvas, //自定义 canvas
      logging: true, //日志开关，发布的时候记得改成false
      width: width, //dom 原始宽度
      height: height //dom 原始高度
    };
  
    await html2canvas(dom, opts).then(async (canvas) => {
      let img = canvas.toDataURL('image/png');
      await exportImg(img, imgName);
      resolve(true)
    });
  
  })
}

export default captureImg
